pub struct PendingWorldChangeToken(u64);Expand description
Runtime token for an in-flight world change request.
The token is intentionally not persisted. It protects async preparation jobs from completing or clearing a newer transition started by the same entity.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for PendingWorldChangeToken
impl Clone for PendingWorldChangeToken
Sourcefn clone(&self) -> PendingWorldChangeToken
fn clone(&self) -> PendingWorldChangeToken
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PendingWorldChangeToken
Sourceimpl Debug for PendingWorldChangeToken
impl Debug for PendingWorldChangeToken
impl Eq for PendingWorldChangeToken
Sourceimpl Hash for PendingWorldChangeToken
impl Hash for PendingWorldChangeToken
Sourceimpl PartialEq for PendingWorldChangeToken
impl PartialEq for PendingWorldChangeToken
impl StructuralPartialEq for PendingWorldChangeToken